@@ -238,6 +238,45 @@ mediaShow.loadSlide = function (slideshow, slideNumber)
     });
 }
 
+//XXX: [RatioProblem] This is the best way until now to do the ratio of the images. I disable it in collective.mediaShow because it implies refactoring CSS in a lot of websites.
+//for now the solution will be maturing here.
+//Basically on CSS I am setting the top and bottom properties of the mediaShowMedia container instead of  setting a fixed height.
+//I am calculating the height of every slideshow depending on the width to fit the ratio and then adding the space necessary for the commands (buttons and descriptions)
+mediaShow.ratioX = 768;
+mediaShow.ratioY = 512;
+mediaShow.infoSize = 60;
+
+mediaShow.findSlideshows = function ()
+{
+  $('.embededMediaShow a').each(function (){
+        //Hide the link that generates the mediaShow
+        $(this).css('display', 'none');
+        $(this).parent().addClass('javascripted');
+
+        //--------------Calculate the height of the whole slideshow so that if fits the configured ratio
+        //XXX: [RatioProblem] This is the best way until now to do the ratio of the images. I disable it in collective.mediaShow because it implies refactoring CSS in a lot of websites.
+        //for now the solution will be maturing here.
+        //Basically on CSS I am setting the top and bottom properties of the mediaShowMedia container instead of  setting a fixed height.
+        //I am calculating the height of every slideshow depending on the width to fit the ratio and then adding the space necessary for the commands (buttons and descriptions)
+        mediaShow.recalculateHeight($(this).parent());
+        
+        //-------------------- Declaration of Slideshow ------------------
+        mediaShow.slideshows.push(
+                                  {"obj": $(this).parent(),
+                                   "url": $(this).attr("href"),
+                                   "currentSlide": 0,
+                                   "slides": new Array(),
+                                   "initialized": false,
+                                   "size": 0,
+                                   "hash": "",
+                                   "presentation": $(this).parent().hasClass('presentationShow'),
+                                   "recursive": !$(this).parent().hasClass('disableRecursive'),
+                                   "height": 0,
+                                   "width": 0
+                                  });
+    });  
+};
+
 Arnolfini.getNextEvent = function (slideshow)
 {
 	if (onSlodeshowSkipNext !== null)
@@ -372,7 +411,9 @@ Arnolfini.resizeImg = function (id, scale)
 
 /*   resizer handler */
 resizer.onResize = function ()
-{	
+{
+	mediaShow.recalculateAllHeights();
+
 	if (resizer.currentMode == "small" || resizer.currentMode == "mobile")
 	{
 		$('#portal-columns').after($("#FrontPageManagerLeft"));
@@ -386,6 +427,7 @@ resizer.onResize = function ()
 	{
 		$('#FrontPageManagerLeft').masonry( 'destroy' );
 		Arnolfini.resizeImg("#FrontPageManagerRight .portletWrapper .portletCollection", "mini");
+		
 		$('#portal-column-one').masonry( 'destroy' );
 		$('#portal-column-two').masonry( 'destroy' );
 		$("#FrontPageManagerRight").after($("#FrontPageManagerLeft"))
